PodBool

Struct PodBool 

#[repr(transparent)]
pub struct PodBool(pub u8);
The standard bool is not a Pod, define a replacement that is.

Tuple Fields

0: u8

Implementations

Source

impl PodBool

pub const fn from_bool(b: bool) -> PodBool

pub const fn is_canonical(&self) -> bool

Returns true if the underlying byte is a canonical boolean value (0 or 1).

Non-canonical values (2–255) are accepted by bytemuck deserialization and convert to true, but two non-canonical PodBool values representing the same logical boolean may fail PartialEq comparison. Use this method to validate account data at deserialization boundaries.